@@ -12,10 +12,10 @@
 
    Copyright 2022, HSPyLib team
 """
+from abc import ABC
 from typing import Generic, List, Optional, TypeVar
 
-from hspylib.core.metaclass.singleton import Singleton
-from hspylib.core.tools.namespace import Namespace
+from hspylib.core.namespace import Namespace
 
 from datasource.crud_entity import CrudEntity
 from datasource.crud_repository import CrudRepository
@@ -25,7 +25,7 @@ E = TypeVar('E', bound=CrudEntity)
 R = TypeVar('R', bound=CrudRepository)
 
 
-class CrudService(Generic[R, E], metaclass=Singleton):
+class CrudService(Generic[R, E], ABC):
 
     def __init__(self, repository: R):
         self._repository = repository
